==> aspose-words-cloud-21.1.0.tar.gz: aspose-words-cloud-21.1.0/asposewordscloud/models/responses/__init__.py <==
from asposewordscloud.models.responses.accept_all_revisions_online_response import AcceptAllRevisionsOnlineResponse
from asposewordscloud.models.responses.append_document_online_response import AppendDocumentOnlineResponse
from asposewordscloud.models.responses.apply_style_to_document_element_online_response import ApplyStyleToDocumentElementOnlineResponse
from asposewordscloud.models.responses.compare_document_online_response import CompareDocumentOnlineResponse
from asposewordscloud.models.responses.copy_style_online_response import CopyStyleOnlineResponse
from asposewordscloud.models.responses.create_or_update_document_property_online_response import CreateOrUpdateDocumentPropertyOnlineResponse
from asposewordscloud.models.responses.delete_all_paragraph_tab_stops_online_response import DeleteAllParagraphTabStopsOnlineResponse
from asposewordscloud.models.responses.delete_border_online_response import DeleteBorderOnlineResponse
from asposewordscloud.models.responses.delete_borders_online_response import DeleteBordersOnlineResponse
from asposewordscloud.models.responses.delete_paragraph_list_format_online_response import DeleteParagraphListFormatOnlineResponse
from asposewordscloud.models.responses.delete_paragraph_tab_stop_online_response import DeleteParagraphTabStopOnlineResponse
from asposewordscloud.models.responses.delete_watermark_online_response import DeleteWatermarkOnlineResponse
from asposewordscloud.models.responses.insert_comment_online_response import InsertCommentOnlineResponse
from asposewordscloud.models.responses.insert_drawing_object_online_response import InsertDrawingObjectOnlineResponse
from asposewordscloud.models.responses.insert_field_online_response import InsertFieldOnlineResponse
from asposewordscloud.models.responses.insert_footnote_online_response import InsertFootnoteOnlineResponse
from asposewordscloud.models.responses.insert_form_field_online_response import InsertFormFieldOnlineResponse
from asposewordscloud.models.responses.insert_header_footer_online_response import InsertHeaderFooterOnlineResponse
from asposewordscloud.models.responses.insert_list_online_response import InsertListOnlineResponse
from asposewordscloud.models.responses.insert_or_update_paragraph_tab_stop_online_response import InsertOrUpdateParagraphTabStopOnlineResponse
from asposewordscloud.models.responses.insert_page_numbers_online_response import InsertPageNumbersOnlineResponse
from asposewordscloud.models.responses.insert_paragraph_online_response import InsertParagraphOnlineResponse
from asposewordscloud.models.responses.insert_run_online_response import InsertRunOnlineResponse
from asposewordscloud.models.responses.insert_style_online_response import InsertStyleOnlineResponse
from asposewordscloud.models.responses.insert_table_cell_online_response import InsertTableCellOnlineResponse
from asposewordscloud.models.responses.insert_table_online_response import InsertTableOnlineResponse
from asposewordscloud.models.responses.insert_table_row_online_response import InsertTableRowOnlineResponse
from asposewordscloud.models.responses.insert_watermark_image_online_response import InsertWatermarkImageOnlineResponse
from asposewordscloud.models.responses.insert_watermark_text_online_response import InsertWatermarkTextOnlineResponse
from asposewordscloud.models.responses.protect_document_online_response import ProtectDocumentOnlineResponse
from asposewordscloud.models.responses.reject_all_revisions_online_response import RejectAllRevisionsOnlineResponse
from asposewordscloud.models.responses.remove_range_online_response import RemoveRangeOnlineResponse
from asposewordscloud.models.responses.replace_text_online_response import ReplaceTextOnlineResponse
from asposewordscloud.models.responses.replace_with_text_online_response import ReplaceWithTextOnlineResponse
from asposewordscloud.models.responses.save_as_online_response import SaveAsOnlineResponse
from asposewordscloud.models.responses.save_as_range_online_response import SaveAsRangeOnlineResponse
from asposewordscloud.models.responses.save_as_tiff_online_response import SaveAsTiffOnlineResponse
from asposewordscloud.models.responses.split_document_online_response import SplitDocumentOnlineResponse
from asposewordscloud.models.responses.unprotect_document_online_response import UnprotectDocumentOnlineResponse
from asposewordscloud.models.responses.update_bookmark_online_response import UpdateBookmarkOnlineResponse
from asposewordscloud.models.responses.update_border_online_response import UpdateBorderOnlineResponse
from asposewordscloud.models.responses.update_comment_online_response import UpdateCommentOnlineResponse
from asposewordscloud.models.responses.update_drawing_object_online_response import UpdateDrawingObjectOnlineResponse
from asposewordscloud.models.responses.update_field_online_response import UpdateFieldOnlineResponse
from asposewordscloud.models.responses.update_fields_online_response import UpdateFieldsOnlineResponse
from asposewordscloud.models.responses.update_footnote_online_response import UpdateFootnoteOnlineResponse
from asposewordscloud.models.responses.update_form_field_online_response import UpdateFormFieldOnlineResponse
from asposewordscloud.models.responses.update_list_level_online_response import UpdateListLevelOnlineResponse
from asposewordscloud.models.responses.update_list_online_response import UpdateListOnlineResponse
from asposewordscloud.models.responses.update_paragraph_format_online_response import UpdateParagraphFormatOnlineResponse
from asposewordscloud.models.responses.update_paragraph_list_format_online_response import UpdateParagraphListFormatOnlineResponse
from asposewordscloud.models.responses.update_run_font_online_response import UpdateRunFontOnlineResponse
from asposewordscloud.models.responses.update_run_online_response import UpdateRunOnlineResponse
from asposewordscloud.models.responses.update_section_page_setup_online_response import UpdateSectionPageSetupOnlineResponse
from asposewordscloud.models.responses.update_style_online_response import UpdateStyleOnlineResponse
from asposewordscloud.models.responses.update_table_cell_format_online_response import UpdateTableCellFormatOnlineResponse
from asposewordscloud.models.responses.update_table_properties_online_response import UpdateTablePropertiesOnlineResponse
from asposewordscloud.models.responses.update_table_row_format_online_response import UpdateTableRowFormatOnlineResponse

==> aspose-words-cloud-22.1.0.tar.gz: aspose-words-cloud-22.1.0/asposewordscloud/models/responses/__init__.py <==
from asposewordscloud.models.responses.accept_all_revisions_online_response import AcceptAllRevisionsOnlineResponse
from asposewordscloud.models.responses.append_document_online_response import AppendDocumentOnlineResponse
from asposewordscloud.models.responses.apply_style_to_document_element_online_response import ApplyStyleToDocumentElementOnlineResponse
from asposewordscloud.models.responses.compare_document_online_response import CompareDocumentOnlineResponse
from asposewordscloud.models.responses.copy_style_online_response import CopyStyleOnlineResponse
from asposewordscloud.models.responses.create_or_update_document_property_online_response import CreateOrUpdateDocumentPropertyOnlineResponse
from asposewordscloud.models.responses.delete_all_paragraph_tab_stops_online_response import DeleteAllParagraphTabStopsOnlineResponse
from asposewordscloud.models.responses.delete_border_online_response import DeleteBorderOnlineResponse
from asposewordscloud.models.responses.delete_borders_online_response import DeleteBordersOnlineResponse
from asposewordscloud.models.responses.delete_paragraph_list_format_online_response import DeleteParagraphListFormatOnlineResponse
from asposewordscloud.models.responses.delete_paragraph_tab_stop_online_response import DeleteParagraphTabStopOnlineResponse
from asposewordscloud.models.responses.delete_watermark_online_response import DeleteWatermarkOnlineResponse
from asposewordscloud.models.responses.insert_comment_online_response import InsertCommentOnlineResponse
from asposewordscloud.models.responses.insert_custom_xml_part_online_response import InsertCustomXmlPartOnlineResponse
from asposewordscloud.models.responses.insert_drawing_object_online_response import InsertDrawingObjectOnlineResponse
from asposewordscloud.models.responses.insert_field_online_response import InsertFieldOnlineResponse
from asposewordscloud.models.responses.insert_footnote_online_response import InsertFootnoteOnlineResponse
from asposewordscloud.models.responses.insert_form_field_online_response import InsertFormFieldOnlineResponse
from asposewordscloud.models.responses.insert_header_footer_online_response import InsertHeaderFooterOnlineResponse
from asposewordscloud.models.responses.insert_list_online_response import InsertListOnlineResponse
from asposewordscloud.models.responses.insert_or_update_paragraph_tab_stop_online_response import InsertOrUpdateParagraphTabStopOnlineResponse
from asposewordscloud.models.responses.insert_page_numbers_online_response import InsertPageNumbersOnlineResponse
from asposewordscloud.models.responses.insert_paragraph_online_response import InsertParagraphOnlineResponse
from asposewordscloud.models.responses.insert_run_online_response import InsertRunOnlineResponse
from asposewordscloud.models.responses.insert_style_online_response import InsertStyleOnlineResponse
from asposewordscloud.models.responses.insert_table_cell_online_response import InsertTableCellOnlineResponse
from asposewordscloud.models.responses.insert_table_online_response import InsertTableOnlineResponse
from asposewordscloud.models.responses.insert_table_row_online_response import InsertTableRowOnlineResponse
from asposewordscloud.models.responses.insert_watermark_image_online_response import InsertWatermarkImageOnlineResponse
from asposewordscloud.models.responses.insert_watermark_text_online_response import InsertWatermarkTextOnlineResponse
from asposewordscloud.models.responses.protect_document_online_response import ProtectDocumentOnlineResponse
from asposewordscloud.models.responses.reject_all_revisions_online_response import RejectAllRevisionsOnlineResponse
from asposewordscloud.models.responses.remove_range_online_response import RemoveRangeOnlineResponse
from asposewordscloud.models.responses.replace_text_online_response import ReplaceTextOnlineResponse
from asposewordscloud.models.responses.replace_with_text_online_response import ReplaceWithTextOnlineResponse
from asposewordscloud.models.responses.save_as_online_response import SaveAsOnlineResponse
from asposewordscloud.models.responses.save_as_range_online_response import SaveAsRangeOnlineResponse
from asposewordscloud.models.responses.save_as_tiff_online_response import SaveAsTiffOnlineResponse
from asposewordscloud.models.responses.split_document_online_response import SplitDocumentOnlineResponse
from asposewordscloud.models.responses.unprotect_document_online_response import UnprotectDocumentOnlineResponse
from asposewordscloud.models.responses.update_bookmark_online_response import UpdateBookmarkOnlineResponse
from asposewordscloud.models.responses.update_border_online_response import UpdateBorderOnlineResponse
from asposewordscloud.models.responses.update_comment_online_response import UpdateCommentOnlineResponse
from asposewordscloud.models.responses.update_custom_xml_part_online_response import UpdateCustomXmlPartOnlineResponse
from asposewordscloud.models.responses.update_drawing_object_online_response import UpdateDrawingObjectOnlineResponse
from asposewordscloud.models.responses.update_field_online_response import UpdateFieldOnlineResponse
from asposewordscloud.models.responses.update_fields_online_response import UpdateFieldsOnlineResponse
from asposewordscloud.models.responses.update_footnote_online_response import UpdateFootnoteOnlineResponse
from asposewordscloud.models.responses.update_form_field_online_response import UpdateFormFieldOnlineResponse
from asposewordscloud.models.responses.update_list_level_online_response import UpdateListLevelOnlineResponse
from asposewordscloud.models.responses.update_list_online_response import UpdateListOnlineResponse
from asposewordscloud.models.responses.update_paragraph_format_online_response import UpdateParagraphFormatOnlineResponse
from asposewordscloud.models.responses.update_paragraph_list_format_online_response import UpdateParagraphListFormatOnlineResponse
from asposewordscloud.models.responses.update_run_font_online_response import UpdateRunFontOnlineResponse
from asposewordscloud.models.responses.update_run_online_response import UpdateRunOnlineResponse
from asposewordscloud.models.responses.update_section_page_setup_online_response import UpdateSectionPageSetupOnlineResponse
from asposewordscloud.models.responses.update_style_online_response import UpdateStyleOnlineResponse
from asposewordscloud.models.responses.update_table_cell_format_online_response import UpdateTableCellFormatOnlineResponse
from asposewordscloud.models.responses.update_table_properties_online_response import UpdateTablePropertiesOnlineResponse
from asposewordscloud.models.responses.update_table_row_format_online_response import UpdateTableRowFormatOnlineResponse
